rnalysis.filtering.CountFilter
==============================

.. currentmodule:: rnalysis.filtering

.. autoclass:: CountFilter

   
   
   
    .. automethod:: __init__
    
    

   
.. autosummary::
    :toctree: .
    
    CountFilter.biotypes
    CountFilter.box_plot
    CountFilter.clustergram
    CountFilter.describe
    CountFilter.difference
    CountFilter.filter_biotype
    CountFilter.filter_by_attribute
    CountFilter.filter_by_row_sum
    CountFilter.filter_low_reads
    CountFilter.filter_percentile
    CountFilter.filter_top_n
    CountFilter.fold_change
    CountFilter.from_folder
    CountFilter.head
    CountFilter.intersection
    CountFilter.normalize_to_rpm
    CountFilter.normalize_with_scaling_factors
    CountFilter.number_filters
    CountFilter.pairplot
    CountFilter.pca
    CountFilter.plot_expression
    CountFilter.print_features
    CountFilter.save_csv
    CountFilter.scatter_sample_vs_sample
    CountFilter.sort
    CountFilter.split_by_attribute
    CountFilter.split_by_percentile
    CountFilter.split_by_reads
    CountFilter.symmetric_difference
    CountFilter.tail
    CountFilter.text_filters
    CountFilter.union
    CountFilter.violin_plot
    
    